==> hiver-common-1.0.0-sources.jar: plus/hiver/common/serviceimpl/UserRoleServiceImpl.java <==
/*
 * Copyright 2023-2025 Licensed under the AGPL License
 */
package plus.hiver.common.serviceimpl;

import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import plus.hiver.common.constant.UserConstant;
import plus.hiver.common.dao.UserDao;
import plus.hiver.common.dao.UserRoleDao;
import plus.hiver.common.entity.User;
import plus.hiver.common.entity.UserRole;
import plus.hiver.common.service.UserRoleService;

import java.util.ArrayList;
import java.util.List;

/**
 * 用户角色接口实现
 *
 * <p>
 * 尊重知识产权，CV 请保留版权，海文科技 https://hiver.cc 出品，不允许非法使用，后果自负
 * </p>
 *
 * @author Yazhi Li
 */
@Slf4j
@Service
@Transactional
public class UserRoleServiceImpl implements UserRoleService {
    @Autowired
    private UserRoleDao userRoleDao;

    @Autowired
    private UserDao userDao;

    @Override
    public UserRoleDao getRepository() {
        return userRoleDao;
    }

    @Override
    public List<UserRole> findByRoleId(Long roleId) {
        return userRoleDao.findByRoleId(roleId);
    }

    @Override
    public List<User> findUserByRoleId(Long roleId) {
        List<UserRole> userRoleList = userRoleDao.findByRoleId(roleId);
        List<User> list = new ArrayList<>();
        for (UserRole ur : userRoleList) {
            User u = userDao.findById(ur.getUserId()).orElse(null);
            if (u != null && UserConstant.USER_STATUS_NORMAL.equals(u.getStatus())) {
                list.add(u);
            }
        }
        return list;
    }

    @Override
    public void deleteByUserId(Long userId) {
        userRoleDao.deleteByUserId(userId);
    }
}

==> hiver-common-1.0.6-sources.jar: plus/hiver/common/serviceimpl/UserRoleServiceImpl.java <==
/*
 * Copyright 2023-2025 Licensed under the AGPL License
 */
package plus.hiver.common.serviceimpl;

import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import plus.hiver.common.base.HiverBaseServiceImpl;
import plus.hiver.common.constant.UserConstant;
import plus.hiver.common.dao.UserDao;
import plus.hiver.common.dao.UserRoleDao;
import plus.hiver.common.entity.User;
import plus.hiver.common.entity.UserRole;
import plus.hiver.common.service.UserRoleService;

import java.util.ArrayList;
import java.util.List;

/**
 * 用户角色接口实现
 *
 * <p>
 * 尊重知识产权，CV 请保留版权，海文科技 https://hiver.cc 出品，不允许非法使用，后果自负
 * </p>
 *
 * @author Yazhi Li
 */
@Slf4j
@Service
@Transactional
public class UserRoleServiceImpl extends HiverBaseServiceImpl<UserRole, Long, UserRoleDao> implements UserRoleService {
    @Resource
    private UserDao userDao;

    public UserRoleServiceImpl(UserRoleDao dao) {
        super(dao);
    }

    @Override
    public List<UserRole> findByRoleId(Long roleId) {
        return dao.findByRoleId(roleId);
    }

    @Override
    public List<User> findUserByRoleId(Long roleId) {
        List<UserRole> userRoleList = dao.findByRoleId(roleId);
        List<User> list = new ArrayList<>();
        for (UserRole ur : userRoleList) {
            User u = userDao.findById(ur.getUserId()).orElse(null);
            if (u != null && UserConstant.USER_STATUS_NORMAL.equals(u.getStatus())) {
                list.add(u);
            }
        }
        return list;
    }

    @Override
    public void deleteByUserId(Long userId) {
        dao.deleteByUserId(userId);
    }
}
